developerscripttools.AbjGrepScript
==================================

.. abjad-lineage:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript

.. autoclass:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__repr__
   :noindex:
